@@ -10,7 +10,7 @@
 #
 
 package Text::Template;
-$Text::Template::VERSION = '1.52';
+$Text::Template::VERSION = '1.53';
 # ABSTRACT: Expand template text with embedded Perl
 
 use strict;
@@ -65,6 +65,7 @@ sub always_prepend {
         my $prepend   = _param('prepend', %a);
         my $alt_delim = _param('delimiters', %a);
         my $broken    = _param('broken', %a);
+        my $encoding  = _param('encoding', %a);
 
         unless (defined $source) {
             require Carp;
@@ -77,10 +78,11 @@ sub always_prepend {
         }
 
         my $self = {
-            TYPE    => $stype,
-            PREPEND => $prepend,
-            UNTAINT => $untaint,
-            BROKEN  => $broken,
+            TYPE     => $stype,
+            PREPEND  => $prepend,
+            UNTAINT  => $untaint,
+            BROKEN   => $broken,
+            ENCODING => $encoding,
             (defined $alt_delim ? (DELIM => $alt_delim) : ())
         };
 
@@ -114,9 +116,16 @@ sub _acquire_data {
             # _load_text already set $ERROR
             return undef;
         }
+
         if ($self->{UNTAINT} && _is_clean($self->{SOURCE})) {
             _unconditionally_untaint($data);
         }
+
+        if (defined $self->{ENCODING}) {
+            require Encode;
+            $data = Encode::decode($self->{ENCODING}, $data, &Encode::FB_CROAK);
+        }
+
         $self->{TYPE}     = 'STRING';
         $self->{FILENAME} = $self->{SOURCE};
         $self->{SOURCE}   = $data;
@@ -600,7 +609,7 @@ Text::Template - Expand template text with embedded Perl
 
 =head1 VERSION
 
-version 1.52
+version 1.53
 
 =head1 SYNOPSIS
 
@@ -626,8 +635,8 @@ version 1.52
  # Pass many variables explicitly
  $hash = { recipient => 'Abed-Nego',
            friends => [ 'me', 'you' ],
-           enemies => { loathsome => 'Bill Gates',
-                        fearsome => 'Larry Ellison' },
+           enemies => { loathsome => 'Saruman',
+                        fearsome => 'Sauron' },
          };
  $text = $template->fill_in(HASH => $hash, ...);
  # $recipient is Abed-Nego,
@@ -684,54 +693,53 @@ encourages functional separation.
 Here's an example of a template, which we'll suppose is stored in the
 file C<formletter.tmpl>:
 
-	Dear {$title} {$lastname},
+    Dear {$title} {$lastname},
 
-	It has come to our attention that you are delinquent in your
-	{$monthname[$last_paid_month]} payment.  Please remit
-	${sprintf("%.2f", $amount)} immediately, or your patellae may
-	be needlessly endangered.
+    It has come to our attention that you are delinquent in your
+    {$monthname[$last_paid_month]} payment.  Please remit
+    ${sprintf("%.2f", $amount)} immediately, or your patellae may
+    be needlessly endangered.
 
-			Love,
+                    Love,
 
-			Mark "Vizopteryx" Dominus
+                    Mark "Vizopteryx" Dominus
 
 The result of filling in this template is a string, which might look
 something like this:
 
-	Dear Mr. Gates,
+    Dear Mr. Smith,
 
-	It has come to our attention that you are delinquent in your
-	February payment.  Please remit
-	$392.12 immediately, or your patellae may
-	be needlessly endangered.
+    It has come to our attention that you are delinquent in your
+    February payment.  Please remit
+    $392.12 immediately, or your patellae may
+    be needlessly endangered.
 
 
-			Love,
+                    Love,
 
-			Mark "Vizopteryx" Dominus
+                    Mark "Vizopteryx" Dominus
 
 Here is a complete program that transforms the example
 template into the example result, and prints it out:
 
-	use Text::Template;
+    use Text::Template;
 
-	my $template = Text::Template->new(SOURCE => 'formletter.tmpl')
-	  or die "Couldn't construct template: $Text::Template::ERROR";
+    my $template = Text::Template->new(SOURCE => 'formletter.tmpl')
+      or die "Couldn't construct template: $Text::Template::ERROR";
 
-	my @monthname = qw(January February March April May June
-                           July August September October November December);
-	my %vars = (title => 'Mr.',
-		    firstname => 'Bill',
-		    lastname => 'Gates',
-		    last_paid_month => 1,   # February
-		    amount => 392.12,
-		    monthname => \@monthname,
-		   );
+    my @monthname = qw(January February March April May June
+                       July August September October November December);
+    my %vars = (title           => 'Mr.',
+                firstname       => 'John',
+                lastname        => 'Smith',
+                last_paid_month => 1,   # February
+                amount          => 392.12,
+                monthname       => \@monthname);
 
-	my $result = $template->fill_in(HASH => \%vars);
+    my $result = $template->fill_in(HASH => \%vars);
 
-	if (defined $result) { print $result }
-	else { die "Couldn't fill in template: $Text::Template::ERROR" }
+    if (defined $result) { print $result }
+    else { die "Couldn't fill in template: $Text::Template::ERROR" }
 
 =head2 Philosophy
 
@@ -754,6 +762,8 @@ If you want a variable interpolated, you write it the way you would in
 Perl.  If you need to make a loop, you can use any of the Perl loop
 constructions.  All the Perl built-in functions are available.
 
+=encoding UTF-8
+
 =head1 Details
 
 =head2 Template Parsing
@@ -768,18 +778,18 @@ A backslash C<\> in front of a brace (or another backslash that is in
 front of a brace) escapes its special meaning.  The result of filling
 out this template:
 
-	\{ The sum of 1 and 2 is {1+2}  \}
+    \{ The sum of 1 and 2 is {1+2}  \}
 
 is
 
-	{ The sum of 1 and 2 is 3  }
+    { The sum of 1 and 2 is 3  }
 
 If you have an unmatched brace, C<Text::Template> will return a
 failure code and a warning about where the problem is.  Backslashes
 that do not precede a brace are passed through unchanged.  If you have
 a template like this:
 
-	{ "String that ends in a newline.\n" }
+    { "String that ends in a newline.\n" }
 
 The backslash inside the string is passed through to Perl unchanged,
 so the C<\n> really does turn into a newline.  See the note at the end
@@ -796,30 +806,30 @@ place of the program fragment itself.
 The fragments are evaluated in order, and side effects from earlier
 fragments will persist into later fragments:
 
-	{$x = @things; ''}The Lord High Chamberlain has gotten {$x}
-	things for me this year.  
-	{ $diff = $x - 17; 
-	  $more = 'more'
-	  if ($diff == 0) {
-	    $diff = 'no';
-	  } elsif ($diff < 0) {
-	    $more = 'fewer';
-	  } 
-          '';
-	} 
-	That is {$diff} {$more} than he gave me last year.
+    {$x = @things; ''}The Lord High Chamberlain has gotten {$x}
+    things for me this year.
+    { $diff = $x - 17;
+      $more = 'more'
+      if ($diff == 0) {
+        $diff = 'no';
+      } elsif ($diff < 0) {
+        $more = 'fewer';
+      }
+      '';
+    }
+    That is {$diff} {$more} than he gave me last year.
 
 The value of C<$x> set in the first line will persist into the next
 fragment that begins on the third line, and the values of C<$diff> and
 C<$more> set in the second fragment will persist and be interpolated
 into the last line.  The output will look something like this:
 
-	The Lord High Chamberlain has gotten 42
-	things for me this year.  
+    The Lord High Chamberlain has gotten 42
+    things for me this year.
 
-	That is 25 more than he gave me last year.
+    That is 25 more than he gave me last year.
 
-That is all the syntax there is.  
+That is all the syntax there is.
 
 =head2 The C<$OUT> variable
 
@@ -828,21 +838,21 @@ motivation for it:  Suppose you are going to pass an array, C<@items>,
 into the template, and you want the template to generate a bulleted
 list with a header, like this:
 
-	Here is a list of the things I have got for you since 1907:
-	  * Ivory
-	  * Apes
-	  * Peacocks
-	  * ...
+    Here is a list of the things I have got for you since 1907:
+      * Ivory
+      * Apes
+      * Peacocks
+      * ...
 
 One way to do it is with a template like this:
 
-	Here is a list of the things I have got for you since 1907:
-	{ my $blist = '';
-          foreach $i (@items) {
-            $blist .= qq{  * $i\n};
-          }    
-          $blist;
-        } 
+    Here is a list of the things I have got for you since 1907:
+    { my $blist = '';
+      foreach $i (@items) {
+          $blist .= qq{  * $i\n};
+      }
+      $blist;
+    }
 
 Here we construct the list in a variable called C<$blist>, which we
 return at the end.  This is a little cumbersome.  There is a shortcut.
@@ -854,11 +864,11 @@ behavior, of replacing the fragment with its return value, is
 disabled; instead the fragment is replaced with the value of C<$OUT>.
 This means that you can write the template above like this:
 
-	Here is a list of the things I have got for you since 1907:
-	{ foreach $i (@items) {
-            $OUT .= "  * $i\n";
-          }    
-        } 
+    Here is a list of the things I have got for you since 1907:
+    { foreach $i (@items) {
+        $OUT .= "  * $i\n";
+      }
+    }
 
 C<$OUT> is reinitialized to the empty string at the start of each
 program fragment.  It is private to C<Text::Template>, so 
@@ -872,11 +882,11 @@ variable C<$Text::Template::ERROR> to contain an explanation of what
 went wrong.  For example, if you try to create a template from a file
 that does not exist, C<$Text::Template::ERROR> will contain something like:
 
-	Couldn't open file xyz.tmpl: No such file or directory
+    Couldn't open file xyz.tmpl: No such file or directory
 
 =head2 C<new>
 
-	$template = new Text::Template ( TYPE => ..., SOURCE => ... );
+    $template = Text::Template->new( TYPE => ..., SOURCE => ... );
 
 This creates and returns a new template object.  C<new> returns
 C<undef> and sets C<$Text::Template::ERROR> if it can't create the
@@ -885,7 +895,7 @@ come from.  C<TYPE> says what kind of object the source is.
 
 The most common type of source is a file:
 
-	new Text::Template ( TYPE => 'FILE', SOURCE => $filename );
+    Text::Template->new( TYPE => 'FILE', SOURCE => $filename );
 
 This reads the template from the specified file.  The filename is
 opened with the Perl C<open> command, so it can be a pipe or anything
@@ -894,18 +904,18 @@ else that makes sense with C<open>.
 The C<TYPE> can also be C<STRING>, in which case the C<SOURCE> should
 be a string:
 
-	new Text::Template ( TYPE => 'STRING', 
-                             SOURCE => "This is the actual template!" );
+    Text::Template->new( TYPE => 'STRING',
+                         SOURCE => "This is the actual template!" );
 
 The C<TYPE> can be C<ARRAY>, in which case the source should be a
 reference to an array of strings.  The concatenation of these strings
 is the template:
 
-	new Text::Template ( TYPE => 'ARRAY', 
-                             SOURCE => [ "This is ", "the actual", 
+    Text::Template->new( TYPE => 'ARRAY',
+                             SOURCE => [ "This is ", "the actual",
                                          " template!",
                                        ]
-                           );
+                       );
 
 The C<TYPE> can be FILEHANDLE, in which case the source should be an
 open filehandle (such as you got from the C<FileHandle> or C<IO::*>
@@ -913,21 +923,21 @@ packages, or a glob, or a reference to a glob).  In this case
 C<Text::Template> will read the text from the filehandle up to
 end-of-file, and that text is the template:
 
-	# Read template source code from STDIN:
-	new Text::Template ( TYPE => 'FILEHANDLE', 
-                             SOURCE => \*STDIN  );
+    # Read template source code from STDIN:
+    Text::Template->new ( TYPE => 'FILEHANDLE', 
+                          SOURCE => \*STDIN  );
 
 If you omit the C<TYPE> attribute, it's taken to be C<FILE>.
 C<SOURCE> is required.  If you omit it, the program will abort.
 
 The words C<TYPE> and C<SOURCE> can be spelled any of the following ways:
 
-	TYPE	SOURCE
-	Type	Source
-	type	source
-	-TYPE	-SOURCE
-	-Type	-Source
-	-type	-source
+    TYPE     SOURCE
+    Type     Source
+    type     source
+    -TYPE    -SOURCE
+    -Type    -Source
+    -type    -source
 
 Pick a style you like and stick with it.
 
@@ -941,6 +951,18 @@ string is the string that signals the beginning of each program
 fragment, and the second string is the string that signals the end of
 each program fragment.  See L<"Alternative Delimiters">, below.
 
+=item C<ENCODING>
+
+You may also add a C<ENCODING> option.  If this option is present, and the
+C<SOURCE> is a C<FILE>, then the data will be decoded from the given encoding
+using the L<Encode> module.  You can use any encoding that L<Encode> recognizes.
+E.g.:
+
+    Text::Template->new(
+        TYPE     => 'FILE',
+        ENCODING => 'UTF-8',
+        SOURCE   => 'xyz.tmpl');
+
 =item C<UNTAINT>
 
 If your program is running in taint mode, you may have problems if
@@ -978,7 +1000,7 @@ overridden in the arguments to C<fill_in>.  See L<C<BROKEN>> below.
 
 =head2 C<compile>
 
-	$template->compile()
+    $template->compile()
 
 Loads all the template text from the template's source, parses and
 compiles it.  If successful, returns true; otherwise returns false and
@@ -994,7 +1016,7 @@ Delimiters">, below.
 
 =head2 C<fill_in>
 
-	$template->fill_in(OPTIONS);
+    $template->fill_in(OPTIONS);
 
 Fills in a template.  Returns the resulting text if successful.
 Otherwise, returns C<undef>  and sets C<$Text::Template::ERROR>.
@@ -1004,12 +1026,12 @@ write the key names in any of the six usual styles as above; this
 means that where this manual says C<PACKAGE> (for example) you can
 actually use any of
 
-	PACKAGE Package package -PACKAGE -Package -package
+    PACKAGE Package package -PACKAGE -Package -package
 
 Pick a style you like and stick with it.  The all-lowercase versions
 may yield spurious warnings about
 
-	Ambiguous use of package => resolved to "package"
+    Ambiguous use of package => resolved to "package"
 
 so you might like to avoid them and use the capitalized versions.
 
@@ -1024,7 +1046,7 @@ C<PACKAGE> specifies the name of a package in which the program
 fragments should be evaluated.  The default is to use the package from
 which C<fill_in> was called.  For example, consider this template:
 
-	The value of the variable x is {$x}.
+    The value of the variable x is {$x}.
 
 If you use C<$template-E<gt>fill_in(PACKAGE =E<gt> 'R')> , then the C<$x> in
 the template is actually replaced with the value of C<$R::x>.  If you
@@ -1040,25 +1062,25 @@ See the section at the end on `Security'.
 
 Here's an example of using C<PACKAGE>:
 
-	Your Royal Highness,
+    Your Royal Highness,
 
-	Enclosed please find a list of things I have gotten
-	for you since 1907:
+    Enclosed please find a list of things I have gotten
+    for you since 1907:
 
-	{ foreach $item (@items) {
+    { foreach $item (@items) {
             $item_no++;
-	    $OUT .= " $item_no. \u$item\n";
-	  }
-	}
+        $OUT .= " $item_no. \u$item\n";
+      }
+    }
 
-	Signed,
-	Lord High Chamberlain
+    Signed,
+    Lord High Chamberlain
 
 We want to pass in an array which will be assigned to the array
 C<@items>.  Here's how to do that:
 
-	@items = ('ivory', 'apes', 'peacocks', );
-	$template->fill_in();
+    @items = ('ivory', 'apes', 'peacocks', );
+    $template->fill_in();
 
 This is not very safe.  The reason this isn't as safe is that if you
 had a variable named C<$item_no> in scope in your program at the point
@@ -1075,8 +1097,8 @@ are safe.
 But if you use the C<PACKAGE> option, you will probably be safe even
 if the template does I<not> declare its variables with C<my>:
 
-	@Q::items = ('ivory', 'apes', 'peacocks', );
-	$template->fill_in(PACKAGE => 'Q');
+    @Q::items = ('ivory', 'apes', 'peacocks', );
+    $template->fill_in(PACKAGE => 'Q');
 
 In this case the template will clobber the variable C<$Q::item_no>,
 which is not related to the one your program was using.
@@ -1094,10 +1116,13 @@ C<HASH> provides an alternative.
 The value for C<HASH> should be a reference to a hash that maps
 variable names to values.  For example, 
 
-	$template->fill_in(HASH => { recipient => "The King",
-				     items => ['gold', 'frankincense', 'myrrh'],
-	                             object => \$self,
-				   });
+    $template->fill_in(
+        HASH => {
+            recipient => "The King",
+            items     => ['gold', 'frankincense', 'myrrh'],
+            object    => \$self,
+        }
+    );
 
 will fill out the template and use C<"The King"> as the value of
 C<$recipient> and the list of items as the value of C<@items>.  Note
@@ -1136,11 +1161,11 @@ that array.  If the I<value> is a reference to a hash, then C<%key> is
 set to that hash.  Similarly if I<value> is any other kind of
 reference.  This means that
 
-	var => "foo"
+    var => "foo"
 
 and
 
-	var => \"foo"
+    var => \"foo"
 
 have almost exactly the same effect.  (The difference is that in the
 former case, the value is copied, and in the latter case it is
@@ -1151,7 +1176,7 @@ aliased.)
 In particular, if you want the template to get an object or any kind,
 you must pass a reference to it:
 
-	$template->fill_in(HASH => { database_handle => \$dbh, ... });
+    $template->fill_in(HASH => { database_handle => \$dbh, ... });
 
 If you do this, the template will have a variable C<$database_handle>
 which is the database handle object.  If you leave out the C<\>, the
@@ -1177,16 +1202,18 @@ of variables.  For example, one set of variables might be the defaults
 for a fill-in form, and the second set might be the user inputs, which
 override the defaults when they are present:
 
-	$template->fill_in(HASH => [\%defaults, \%user_input]);
+    $template->fill_in(HASH => [\%defaults, \%user_input]);
 
 You can also use this to set two variables with the same name:
 
-	$template->fill_in(HASH => [{ v => "The King" },
-                                    { v => [1,2,3] },
-	                           ]
-                          );
+    $template->fill_in(
+        HASH => [
+            { v => "The King" },
+            { v => [1,2,3] }
+        ]
+    );
 
-This sets C<$v> to C<"The King"> and C<@v> to C<(1,2,3)>.	
+This sets C<$v> to C<"The King"> and C<@v> to C<(1,2,3)>.
 
 =item C<BROKEN>
 
@@ -1212,19 +1239,19 @@ fragment that cased the error.
 If you don't specify a C<BROKEN> function, C<Text::Template> supplies
 a default one that returns something like
 
-	Program fragment delivered error ``Illegal division by 0 at
-	template line 37''
+    Program fragment delivered error ``Illegal division by 0 at
+    template line 37''
 
 (Note that the format of this message has changed slightly since
 version 1.31.)  The return value of the C<BROKEN> function is
 interpolated into the template at the place the error occurred, so
 that this template:
 
-	(3+4)*5 = { 3+4)*5 }
+    (3+4)*5 = { 3+4)*5 }
 
 yields this result:
 
-	(3+4)*5 = Program fragment delivered error ``syntax error at template line 1''
+    (3+4)*5 = Program fragment delivered error ``syntax error at template line 1''
 
 If you specify a value for the C<BROKEN> attribute, it should be a
 reference to a function that C<fill_in> can call instead of the
@@ -1268,23 +1295,24 @@ The C<BROKEN> function could also use the C<BROKEN_ARG> as a reference
 to store an error message or some other information that it wants to
 communicate back to the caller.  For example:
 
-	$error = '';
+    $error = '';
 
-	sub my_broken {	
-	   my %args = @_;
-	   my $err_ref = $args{arg};
-	   ...
-	   $$err_ref = "Some error message";
-	   return undef;
-	}
+    sub my_broken {
+       my %args = @_;
+       my $err_ref = $args{arg};
+       ...
+       $$err_ref = "Some error message";
+       return undef;
+    }
 
-	$template->fill_in(BROKEN => \&my_broken,
-			   BROKEN_ARG => \$error,
-			  );
+    $template->fill_in(
+        BROKEN     => \&my_broken,
+        BROKEN_ARG => \$error
+    );
 
-	if ($error) {
-	  die "It didn't work: $error";
-	}
+    if ($error) {
+      die "It didn't work: $error";
+    }
 
 If one of the program fragments in the template fails, it will call
 the C<BROKEN> function, C<my_broken>, and pass it the C<BROKEN_ARG>,
@@ -1348,7 +1376,7 @@ the C<OUTPUT> option to C<fill_in>, the value should be a filehandle.
 The generated text will be printed to this filehandle as it is
 constructed.  For example:
 
-	$template->fill_in(OUTPUT => \*STDOUT, ...);
+    $template->fill_in(OUTPUT => \*STDOUT, ...);
 
 fills in the C<$template> as usual, but the results are immediately
 printed to STDOUT.  This may result in the output appearing more
@@ -1395,17 +1423,17 @@ any results.
 
 An example:
 
-	$Q::name = 'Donald';
-	$Q::amount = 141.61;
-	$Q::part = 'hyoid bone';
+    $Q::name = 'Donald';
+    $Q::amount = 141.61;
+    $Q::part = 'hyoid bone';
 
-	$text = Text::Template->fill_this_in( <<'EOM', PACKAGE => Q);
-	Dear {$name},
-	You owe me \\${sprintf('%.2f', $amount)}.  
-	Pay or I will break your {$part}.
-		Love,
-		Grand Vizopteryx of Irkutsk.
-	EOM
+    $text = Text::Template->fill_this_in( <<'EOM', PACKAGE => Q);
+    Dear {$name},
+    You owe me \\${sprintf('%.2f', $amount)}.
+    Pay or I will break your {$part}.
+        Love,
+        Grand Vizopteryx of Irkutsk.
+    EOM
 
 Notice how we included the template in-line in the program by using a
 `here document' with the C<E<lt>E<lt>> notation.
@@ -1425,14 +1453,14 @@ four years ago and it is too late to change it.
 C<fill_in_string> is exactly like C<fill_this_in> except that it is
 not a method and you can omit the C<Text::Template-E<gt>> and just say
 
-	print fill_in_string(<<'EOM', ...);
-	Dear {$name},
-	  ...
-	EOM
+    print fill_in_string(<<'EOM', ...);
+    Dear {$name},
+      ...
+    EOM
 
 To use C<fill_in_string>, you need to say
 
-	use Text::Template 'fill_in_string';
+    use Text::Template 'fill_in_string';
 
 at the top of your program.   You should probably use
 C<fill_in_string> instead of C<fill_this_in>.
@@ -1441,7 +1469,7 @@ C<fill_in_string> instead of C<fill_this_in>.
 
 If you import C<fill_in_file>, you can say
 
-	$text = fill_in_file(filename, ...);
+    $text = fill_in_file(filename, ...);
 
 The C<...> are passed to C<fill_in> as above.  The filename is the
 name of the file that contains the template you want to fill in.  It
@@ -1458,7 +1486,7 @@ People always ask for this.  ``Why don't you have an include
 function?'' they want to know.  The short answer is this is Perl, and
 Perl already has an include function.  If you want it, you can just put
 
-	{qx{cat filename}}
+    {qx{cat filename}}
 
 into your template.  VoilE<agrave>.
 
@@ -1466,19 +1494,19 @@ If you don't want to use C<cat>, you can write a little four-line
 function that opens a file and dumps out its contents, and call it
 from the template.  I wrote one for you.  In the template, you can say
 
-	{Text::Template::_load_text(filename)}
+    {Text::Template::_load_text(filename)}
 
 If that is too verbose, here is a trick.  Suppose the template package
 that you are going to be mentioning in the C<fill_in> call is package
 C<Q>.  Then in the main program, write
 
-	*Q::include = \&Text::Template::_load_text;
+    *Q::include = \&Text::Template::_load_text;
 
 This imports the C<_load_text> function into package C<Q> with the
 name C<include>.  From then on, any template that you fill in with
 package C<Q> can say
 
-	{include(filename)}
+    {include(filename)}
 
 to insert the text from the named file at that point.  If you are
 using the C<HASH> option instead, just put C<include =E<gt>
@@ -1489,7 +1517,7 @@ Suppose you don't want to insert a plain text file, but rather you
 want to include one template within another?  Just use C<fill_in_file>
 in the template itself:
 
-	{Text::Template::fill_in_file(filename)}
+    {Text::Template::fill_in_file(filename)}
 
 You can do the same importing trick if this is too much to type.
 
@@ -1499,8 +1527,8 @@ You can do the same importing trick if this is too much to type.
 
 People are frequently surprised when this doesn't work:
 
-	my $recipient = 'The King';
-	my $text = fill_in_file('formletter.tmpl');
+    my $recipient = 'The King';
+    my $text = fill_in_file('formletter.tmpl');
 
 The text C<The King> doesn't get into the form letter.  Why not?
 Because C<$recipient> is a C<my> variable, and the whole point of
@@ -1513,12 +1541,12 @@ private variable, and in this case you don't want the variable to be
 private.  Put the variables into package variables in some other
 package, and use the C<PACKAGE> option to C<fill_in>:
 
-	$Q::recipient = $recipient;
-	my $text = fill_in_file('formletter.tmpl', PACKAGE => 'Q');
+    $Q::recipient = $recipient;
+    my $text = fill_in_file('formletter.tmpl', PACKAGE => 'Q');
 
 or pass the names and values in a hash with the C<HASH> option:
 
-	my $text = fill_in_file('formletter.tmpl', HASH => { recipient => $recipient });
+    my $text = fill_in_file('formletter.tmpl', HASH => { recipient => $recipient });
 
 =head2 Security Matters
 
@@ -1531,19 +1559,19 @@ rest of your program and wreck something.
 Nevertheless, there's really no way (except with C<Safe>) to protect
 against a template that says
 
-	{ $Important::Secret::Security::Enable = 0; 
-	  # Disable security checks in this program 
-	}
+    { $Important::Secret::Security::Enable = 0;
+      # Disable security checks in this program
+    }
 
 or
 
-	{ $/ = "ho ho ho";   # Sabotage future uses of <FH>.
-	  # $/ is always a global variable
-	}
+    { $/ = "ho ho ho";   # Sabotage future uses of <FH>.
+      # $/ is always a global variable
+    }
 
 or even
 
-	{ system("rm -rf /") }
+    { system("rm -rf /") }
 
 so B<don't> go filling in templates unless you're sure you know what's
 in them.  If you're worried, or you can't trust the person who wrote
@@ -1571,7 +1599,7 @@ an alternative set of delimiters with the C<DELIMITERS> option.  For
 example, if you would like code fragments to be delimited by C<[@-->
 and C<--@]> instead of C<{> and C<}>, use
 
-	... DELIMITERS => [ '[@--', '--@]' ], ...
+    ... DELIMITERS => [ '[@--', '--@]' ], ...
 
 Note that these delimiters are I<literal strings>, not regexes.  (I
 tried for regexes, but it complicates the lexical analysis too much.)
@@ -1584,16 +1612,16 @@ as they nest properly.  This means that if for some reason you
 absolutely must have a program fragment that mentions one of the
 delimiters, like this:
 
-	[@--
-		print "Oh no, a delimiter: --@]\n"
-	--@]
+    [@--
+        print "Oh no, a delimiter: --@]\n"
+    --@]
 
 you may be able to make it work by doing this instead:
 
-	[@--
-		# Fake matching delimiter in a comment: [@--
-		print "Oh no, a delimiter: --@]\n"
-	--@]
+    [@--
+        # Fake matching delimiter in a comment: [@--
+        print "Oh no, a delimiter: --@]\n"
+    --@]
 
 It may be safer to choose delimiters that begin with a newline
 character.  
@@ -1610,18 +1638,18 @@ undeclared variables and the like.  But each code fragment is a
 separate lexical scope, so you have to turn on C<strict> at the top of
 each and every code fragment:
 
-	{ use strict;
-	  use vars '$foo';
-	  $foo = 14;
-	  ...
-	}
+    { use strict;
+      use vars '$foo';
+      $foo = 14;
+      ...
+    }
 
-	...
+    ...
 
-	{ # we forgot to put `use strict' here
-	  my $result = $boo + 12;    # $boo is misspelled and should be $foo
-	  # No error is raised on `$boo'
-	}
+    { # we forgot to put `use strict' here
+      my $result = $boo + 12;    # $boo is misspelled and should be $foo
+      # No error is raised on `$boo'
+    }
 
 Because we didn't put C<use strict> at the top of the second fragment,
 it was only active in the first fragment, and we didn't get any
@@ -1634,25 +1662,25 @@ added to the beginning of each program fragment.
 
 When you make a call to C<fill_in>, you can specify a
 
-	PREPEND => 'some perl statements here'
+    PREPEND => 'some perl statements here'
 
 option; the statements will be prepended to each program fragment for
 that one call only.  Suppose that the C<fill_in> call included a
 
-	PREPEND => 'use strict;'
+    PREPEND => 'use strict;'
 
 option, and that the template looked like this:
 
-	{ use vars '$foo';
-	  $foo = 14;
-	  ...
-	}
+    { use vars '$foo';
+      $foo = 14;
+      ...
+    }
 
-	...
+    ...
 
-	{ my $result = $boo + 12;    # $boo is misspelled and should be $foo
-	  ...
-	}
+    { my $result = $boo + 12;    # $boo is misspelled and should be $foo
+      ...
+    }
 
 The code in the second fragment would fail, because C<$boo> has not
 been declared.  C<use strict> was implied, even though you did not
@@ -1666,7 +1694,7 @@ that template.  If the C<fill_in> call has its own C<PREPEND> option,
 this overrides the one specified at the time you created the
 template.  Finally, you can make the class method call
 
-	Text::Template->always_prepend('perl statements');
+    Text::Template->always_prepend('perl statements');
 
 If you do this, then call calls to C<fill_in> for I<any> template will
 attach the perl statements to the beginning of each program fragment,
@@ -1677,21 +1705,21 @@ pass STRICT => 1 to fill_in when also passing the HASH option.
 
 Suppose that the C<fill_in> call included both
 
-	HASH => {$foo => ''} and
-	STRICT => 1
+    HASH   => {$foo => ''} and
+    STRICT => 1
 
 options, and that the template looked like this:
 
-	{ 
-	  $foo = 14;
-	  ...
-	}
+    {
+      $foo = 14;
+      ...
+    }
 
-	...
+    ...
 
-	{ my $result = $boo + 12;    # $boo is misspelled and should be $foo
-	  ...
-	}
+    { my $result = $boo + 12;    # $boo is misspelled and should be $foo
+      ...
+    }
 
 The code in the second fragment would fail, because C<$boo> has not
 been declared. C<use strict> was implied, even though you did not
@@ -1714,7 +1742,7 @@ first one that it finds.
 In a subclass of C<Text::Template>, this last possibility is
 ambiguous.  Suppose C<S> is a subclass of C<Text::Template>.  Should 
 
-	Text::Template->always_prepend(...);
+    Text::Template->always_prepend(...);
 
 affect objects in class C<Derived>?  The answer is that you can have it
 either way.  
@@ -1728,11 +1756,11 @@ which the template object belongs.  If it doesn't find any value, it
 looks in C<$GLOBAL_PREPEND{'Text::Template'}>.  This means that
 objects in class C<Derived> I<will> be affected by
 
-	Text::Template->always_prepend(...);
+    Text::Template->always_prepend(...);
 
 I<unless> there is also a call to
 
-	Derived->always_prepend(...);
+    Derived->always_prepend(...);
 
 So when you're designing your derived class, you can arrange to have
 your objects ignore C<Text::Template::always_prepend> calls by simply
@@ -1747,8 +1775,8 @@ method to get an arbitrary effect.
 
 Jennifer D. St Clair asks:
 
-	> Most of my pages contain JavaScript and Stylesheets.
-        > How do I change the template identifier?  
+    > Most of my pages contain JavaScript and Stylesheets.
+    > How do I change the template identifier?
 
 Jennifer is worried about the braces in the JavaScript being taken as
 the delimiters of the Perl program fragments.  Of course, disaster
@@ -1761,60 +1789,60 @@ some reason, there are  two easy workarounds:
 1. You can put C<\> in front of C<{>, C<}>, or C<\> to remove its
 special meaning.  So, for example, instead of
 
-	    if (br== "n3") { 
-		// etc.
-	    }
+    if (br== "n3") { 
+        // etc.
+    }
 
 you can put
 
-	    if (br== "n3") \{ 
-		// etc.
-	    \}
+    if (br== "n3") \{
+        // etc.
+    \}
 
 and it'll come out of the template engine the way you want.
 
 But here is another method that is probably better.  To see how it
 works, first consider what happens if you put this into a template:
 
-	    { 'foo' }
+    { 'foo' }
 
 Since it's in braces, it gets evaluated, and obviously, this is going
 to turn into
 
-	    foo
+    foo
 
 So now here's the trick: In Perl, C<q{...}> is the same as C<'...'>.
 So if we wrote
 
-	    {q{foo}}
+    {q{foo}}
 
 it would turn into 
 
-	    foo
+    foo
 
 So for your JavaScript, just write
 
-	    {q{if (br== "n3") { 
-	  	 // etc.
-	       }}
-	    }
+    {q{if (br== "n3") {
+       // etc.
+       }}
+    }
 
 and it'll come out as
 
-	      if (br== "n3") { 
-	  	  // etc.
-	      }
+    if (br== "n3") {
+        // etc.
+    }
 
 which is what you want.
 
-=head2 Shut Up!
+head2 Shut Up!
 
 People sometimes try to put an initialization section at the top of
 their templates, like this:
 
-	{ ...
-	  $var = 17;
-	}
+    { ...
+        $var = 17;
+    }
 
 Then they complain because there is a C<17> at the top of the output
 that they didn't want to have there.  
@@ -1827,18 +1855,18 @@ and have the recipient filled in.
 
 To prevent the 17 from appearing in the output is very simple:
 
-	{ ...
-	  $var = 17;
-	  '';
-	}
+    { ...
+        $var = 17;
+        '';
+    }
 
 Now the last expression evaluated yields the empty string, which is
 invisible.  If you don't like the way this looks, use
 
-	{ ...
-	  $var = 17;
-	  ($SILENTLY);
-	}
+    { ...
+        $var = 17;
+        ($SILENTLY);
+    }
 
 instead.  Presumably, C<$SILENTLY> has no value, so nothing will be
 interpolated.  This is what is known as a `trick'.
@@ -1887,28 +1915,28 @@ C<\}> signal a literal brace.
 
 Examples:
 
-	\{ foo \}
+    \{ foo \}
 
 is I<not> evaluated, because the C<\> before the braces signals that
 they should be taken literally.  The result in the output looks like this: 
 
-	{ foo }
+    { foo }
 
 This is a syntax error:
 
-	{ "foo}" }
+    { "foo}" }
 
 because C<Text::Template> thinks that the code ends at the first C<}>,
 and then gets upset when it sees the second one.  To make this work
 correctly, use
 
-	{ "foo\}" }
+    { "foo\}" }
 
 This passes C<"foo}"> to Perl for evaluation.  Note there's no C<\> in
 the evaluated code.  If you really want a C<\> in the evaluated code,
 use
 
-	{ "foo\\\}" }
+    { "foo\\\}" }
 
 This passes C<"foo\}"> to Perl for evaluation.
 
@@ -1928,20 +1956,20 @@ If it really, really bothers you, you can import a function called
 C<TTerror> that returns the current value of the C<$ERROR> variable.
 So you can say:
 
-	use Text::Template 'TTerror';
+    use Text::Template 'TTerror';
 
-	my $template = new Text::Template (SOURCE => $filename);
-	unless ($template) {
-	  my $err = TTerror;
-	  die "Couldn't make template: $err; aborting";
-	}
+    my $template = Text::Template->new(SOURCE => $filename);
+    unless ($template) {
+        my $err = TTerror;
+        die "Couldn't make template: $err; aborting";
+    }
 
 I don't see what benefit this has over just doing this:
 
-	use Text::Template;
+    use Text::Template;
 
-	my $template = new Text::Template (SOURCE => $filename)
-	  or die "Couldn't make template: $Text::Template::ERROR; aborting";
+    my $template = Text::Template->new(SOURCE => $filename)
+        or die "Couldn't make template: $Text::Template::ERROR; aborting";
 
 But if it makes you happy to do it that way, go ahead.
 
@@ -1955,12 +1983,12 @@ into their template output.
 It's totally straightforward.  Just call the C<CGI> functions from
 inside the template:
 
-	{ $q->checkbox_group(NAME => 'toppings',
-		  	     LINEBREAK => true,
-			     COLUMNS => 3,
-			     VALUES => \@toppings,
-			    );
-	}
+    { $q->checkbox_group(NAME      => 'toppings',
+                         LINEBREAK => true,
+                         COLUMNS   => 3,
+                         VALUES    => \@toppings,
+                        );
+    }
 
 =head2 Automatic preprocessing of program fragments
 
@@ -1990,77 +2018,290 @@ Maintainership transferred to Michael Schout E<lt>mschout@cpan.orgE<gt> in versi
 Many thanks to the following people for offering support,
 encouragement, advice, bug reports, and all the other good stuff.  
 
-David H. Adler /
-Joel Appelbaum /
-Klaus Arnhold /
-AntE<oacute>nio AragE<atilde>o /
-Kevin Atteson /
-Chris.Brezil /
-Mike Brodhead /
-Tom Brown /
-Dr. Frank Bucolo /
-Tim Bunce /
-Juan E. Camacho /
-Itamar Almeida de Carvalho /
-Joseph Cheek /
-Gene Damon /
-San Deng /
-Bob Dougherty /
-Marek Grac /
-Dan Franklin /
-gary at dls.net /
-Todd A. Green /
-Donald L. Greer Jr. /
-Michelangelo Grigni /
-Zac Hansen /
-Tom Henry /
-Jarko Hietaniemi /
-Matt X. Hunter /
-Robert M. Ioffe /
-Daniel LaLiberte /
-Reuven M. Lerner /
-Trip Lilley / 
-Yannis Livassof /
-Val Luck /
-Kevin Madsen /
-David Marshall /
-James Mastros /
-Joel Meulenberg /
-Jason Moore /
-Sergey Myasnikov /
-Chris Nandor /
-Bek Oberin /
-Steve Palincsar /
-Ron Pero /
-Hans Persson /
-Sean Roehnelt /
-Jonathan Roy /
-Shabbir J. Safdar /
-Jennifer D. St Clair /
-Uwe Schneider /
-Randal L. Schwartz /
-Michael G Schwern /
-Yonat Sharon /
-Brian C. Shensky /
-Niklas Skoglund /
-Tom Snee /
-Fred Steinberg /
-Hans Stoop /
-Michael J. Suzio /
-Dennis Taylor /
-James H. Thompson /
-Shad Todd /
-Lieven Tomme /
-Lorenzo Valdettaro /
-Larry Virden /
-Andy Wardley /
-Archie Warnock /
-Chris Wesley /
-Matt Womer /
-Andrew G Wood /
-Daini Xie /
+=over 4
+
+=item *
+
+Andrew G Wood
+
+=item *
+
+Andy Wardley
+
+=item *
+
+António Aragão
+
+=item *
+
+Archie Warnock
+
+=item *
+
+Bek Oberin
+
+=item *
+
+Bob Dougherty
+
+=item *
+
+Brian C. Shensky
+
+=item *
+
+Chris Nandor
+
+=item *
+
+Chris Wesley
+
+=item *
+
+Chris.Brezil
+
+=item *
+
+Daini Xie
+
+=item *
+
+Dan Franklin
+
+=item *
+
+Daniel LaLiberte
+
+=item *
+
+David H. Adler
+
+=item *
+
+David Marshall
+
+=item *
+
+Dennis Taylor
+
+=item *
+
+Donald L. Greer Jr.
+
+=item *
+
+Dr. Frank Bucolo
+
+=item *
+
+Fred Steinberg
+
+=item *
+
+Gene Damon
+
+=item *
+
+Hans Persson
+
+=item *
+
+Hans Stoop
+
+=item *
+
+Itamar Almeida de Carvalho
+
+=item *
+
+James H. Thompson
+
+=item *
+
+James Mastros
+
+=item *
+
+Jarko Hietaniemi
+
+=item *
+
+Jason Moore
+
+=item *
+
+Jennifer D. St Clair
+
+=item *
+
+Joel Appelbaum
+
+=item *
+
+Joel Meulenberg
+
+=item *
+
+Jonathan Roy
+
+=item *
+
+Joseph Cheek
+
+=item *
+
+Juan E. Camacho
+
+=item *
+
+Kevin Atteson
+
+=item *
+
+Kevin Madsen
+
+=item *
+
+Klaus Arnhold
+
+=item *
+
+Larry Virden
+
+=item *
+
+Lieven Tomme
+
+=item *
+
+Lorenzo Valdettaro
+
+=item *
+
+Marek Grac
+
+=item *
+
+Matt Womer
+
+=item *
+
+Matt X. Hunter
+
+=item *
+
+Michael G Schwern
+
+=item *
+
+Michael J. Suzio
+
+=item *
+
 Michaely Yeung
 
+=item *
+
+Michelangelo Grigni
+
+=item *
+
+Mike Brodhead
+
+=item *
+
+Niklas Skoglund
+
+=item *
+
+Randal L. Schwartz
+
+=item *
+
+Reuven M. Lerner
+
+=item *
+
+Robert M. Ioffe
+
+=item *
+
+Ron Pero
+
+=item *
+
+San Deng
+
+=item *
+
+Sean Roehnelt
+
+=item *
+
+Sergey Myasnikov
+
+=item *
+
+Shabbir J. Safdar
+
+=item *
+
+Shad Todd
+
+=item *
+
+Steve Palincsar
+
+=item *
+
+Tim Bunce
+
+=item *
+
+Todd A. Green
+
+=item *
+
+Tom Brown
+
+=item *
+
+Tom Henry
+
+=item *
+
+Tom Snee
+
+=item *
+
+Trip Lilley
+
+=item *
+
+Uwe Schneider
+
+=item *
+
+Val Luck
+
+=item *
+
+Yannis Livassof
+
+=item *
+
+Yonat Sharon
+
+=item *
+
+Zac Hansen
+
+=item *
+
+gary at dls.net
+
+=back
+
 Special thanks to:
 
 =over 2
